==> core-1.39.0-sources.jar: software/amazon/awscdk/core/DefaultStackSynthesizer.java <==
package software.amazon.awscdk.core;

/**
 * Uses conventionally named roles and reify asset storage locations.
 * <p>
 * This synthesizer is the only StackSynthesizer that generates
 * an asset manifest, and is required to deploy CDK applications using the
 * <code>&#64;aws-cdk/app-delivery</code> CI/CD library.
 * <p>
 * Requires the environment to have been bootstrapped with Bootstrap Stack V2.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.5.0 (build 46538f8)", date = "2020-05-15T23:35:45.955Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.DefaultStackSynthesizer")
public class DefaultStackSynthesizer extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.IStackSynthesizer {

    protected DefaultStackSynthesizer(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DefaultStackSynthesizer(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        DEFAULT_ASSET_PUBLISHING_ROLE_ARN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_ASSET_PUBLISHING_ROLE_ARN", java.lang.String.class);
        DEFAULT_CLOUDFORMATION_ROLE_ARN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_CLOUDFORMATION_ROLE_ARN", java.lang.String.class);
        DEFAULT_DEPLOY_ACTION_ROLE_ARN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_DEPLOY_ACTION_ROLE_ARN", java.lang.String.class);
        DEFAULT_FILE_ASSETS_BUCKET_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_FILE_ASSETS_BUCKET_NAME", java.lang.String.class);
        DEFAULT_IMAGE_ASSETS_REPOSITORY_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_IMAGE_ASSETS_REPOSITORY_NAME", java.lang.String.class);
        DEFAULT_QUALIFIER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_QUALIFIER", java.lang.String.class);
    }

    /**
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DefaultStackSynthesizer(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.DefaultStackSynthesizerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DefaultStackSynthesizer() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Register a Docker Image Asset.
     * <p>
     * Returns the parameters that can be used to refer to the asset inside the template.
     * <p>
     * @param asset This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.DockerImageAssetLocation addDockerImageAsset(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.DockerImageAssetSource asset) {
        return this.jsiiCall("addDockerImageAsset", software.amazon.awscdk.core.DockerImageAssetLocation.class, new Object[] { java.util.Objects.requireNonNull(asset, "asset is required") });
    }

    /**
     * Register a File Asset.
     * <p>
     * Returns the parameters that can be used to refer to the asset inside the template.
     * <p>
     * @param asset This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.FileAssetLocation addFileAsset(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.FileAssetSource asset) {
        return this.jsiiCall("addFileAsset", software.amazon.awscdk.core.FileAssetLocation.class, new Object[] { java.util.Objects.requireNonNull(asset, "asset is required") });
    }

    /**
     * Bind to the stack this environment is going to be used on.
     * <p>
     * Must be called before any of the other methods are called.
     * <p>
     * @param stack This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Stack stack) {
        this.jsiiCall("bind", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(stack, "stack is required") });
    }

    /**
     * Synthesize all artifacts required for the stack into the session.
     * <p>
     * @param session This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void synthesizeStackArtifacts(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.ISynthesisSession session) {
        this.jsiiCall("synthesizeStackArtifacts", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(session, "session is required") });
    }

    /**
     * Default asset publishing role ARN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_ASSET_PUBLISHING_ROLE_ARN;

    /**
     * Default CloudFormation role ARN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_CLOUDFORMATION_ROLE_ARN;

    /**
     * Default deploy action role ARN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_DEPLOY_ACTION_ROLE_ARN;

    /**
     * Default file assets bucket name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_FILE_ASSETS_BUCKET_NAME;

    /**
     * Default image assets repository name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_IMAGE_ASSETS_REPOSITORY_NAME;

    /**
     * Default ARN qualifier.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_QUALIFIER;

    /**
     * A fluent builder for {@link software.amazon.awscdk.core.DefaultStackSynthesizer}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.core.DefaultStackSynthesizerProps.Builder props;

        private Builder() {
        }

        /**
         * External ID to use when assuming role for asset publishing.
         * <p>
         * Default: - No external ID
         * <p>
         * @return {@code this}
         * @param assetPublishingExternalId External ID to use when assuming role for asset publishing. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder assetPublishingExternalId(final java.lang.String assetPublishingExternalId) {
            this.props().assetPublishingExternalId(assetPublishingExternalId);
            return this;
        }

        /**
         * The role to use to publish assets to this environment.
         * <p>
         * You must supply this if you have given a non-standard name to the publishing role.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_ASSET_PUBLISHING_ROLE_ARN
         * <p>
         * @return {@code this}
         * @param assetPublishingRoleArn The role to use to publish assets to this environment. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder assetPublishingRoleArn(final java.lang.String assetPublishingRoleArn) {
            this.props().assetPublishingRoleArn(assetPublishingRoleArn);
            return this;
        }

        /**
         * The role CloudFormation will assume when deploying the Stack.
         * <p>
         * You must supply this if you have given a non-standard name to the execution role.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_CLOUDFORMATION_ROLE_ARN
         * <p>
         * @return {@code this}
         * @param cloudFormationExecutionRole The role CloudFormation will assume when deploying the Stack. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudFormationExecutionRole(final java.lang.String cloudFormationExecutionRole) {
            this.props().cloudFormationExecutionRole(cloudFormationExecutionRole);
            return this;
        }

        /**
         * The role to assume to initiate a deployment in this environment.
         * <p>
         * You must supply this if you have given a non-standard name to the publishing role.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_DEPLOY_ACTION_ROLE_ARN
         * <p>
         * @return {@code this}
         * @param deployActionRoleArn The role to assume to initiate a deployment in this environment. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deployActionRoleArn(final java.lang.String deployActionRoleArn) {
            this.props().deployActionRoleArn(deployActionRoleArn);
            return this;
        }

        /**
         * Name of the S3 bucket to hold file assets.
         * <p>
         * You must supply this if you have given a non-standard name to the staging bucket.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_FILE_ASSETS_BUCKET_NAME
         * <p>
         * @return {@code this}
         * @param fileAssetsBucketName Name of the S3 bucket to hold file assets. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder fileAssetsBucketName(final java.lang.String fileAssetsBucketName) {
            this.props().fileAssetsBucketName(fileAssetsBucketName);
            return this;
        }

        /**
         * Name of the ECR repository to hold Docker Image assets.
         * <p>
         * You must supply this if you have given a non-standard name to the ECR repository.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_IMAGE_ASSETS_REPOSITORY_NAME
         * <p>
         * @return {@code this}
         * @param imageAssetsRepositoryName Name of the ECR repository to hold Docker Image assets. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder imageAssetsRepositoryName(final java.lang.String imageAssetsRepositoryName) {
            this.props().imageAssetsRepositoryName(imageAssetsRepositoryName);
            return this;
        }

        /**
         * Qualifier to disambiguate multiple environments in the same account.
         * <p>
         * You can use this and leave the other naming properties empty if you have deployed
         * the bootstrap environment with standard names but only differnet qualifiers.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_QUALIFIER
         * <p>
         * @return {@code this}
         * @param qualifier Qualifier to disambiguate multiple environments in the same account. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder qualifier(final java.lang.String qualifier) {
            this.props().qualifier(qualifier);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.core.DefaultStackSynthesizer}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.DefaultStackSynthesizer build() {
            return new software.amazon.awscdk.core.DefaultStackSynthesizer(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.core.DefaultStackSynthesizerProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.core.DefaultStackSynthesizerProps.Builder();
            }
            return this.props;
        }
    }
}

==> core-1.40.0-sources.jar: software/amazon/awscdk/core/DefaultStackSynthesizer.java <==
package software.amazon.awscdk.core;

/**
 * Uses conventionally named roles and reify asset storage locations.
 * <p>
 * This synthesizer is the only StackSynthesizer that generates
 * an asset manifest, and is required to deploy CDK applications using the
 * <code>&#64;aws-cdk/app-delivery</code> CI/CD library.
 * <p>
 * Requires the environment to have been bootstrapped with Bootstrap Stack V2.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.5.0 (build 46538f8)", date = "2020-05-20T13:23:04.636Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.DefaultStackSynthesizer")
public class DefaultStackSynthesizer extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.IStackSynthesizer {

    protected DefaultStackSynthesizer(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DefaultStackSynthesizer(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        DEFAULT_ASSET_PUBLISHING_ROLE_ARN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_ASSET_PUBLISHING_ROLE_ARN", java.lang.String.class);
        DEFAULT_CLOUDFORMATION_ROLE_ARN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_CLOUDFORMATION_ROLE_ARN", java.lang.String.class);
        DEFAULT_DEPLOY_ROLE_ARN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_DEPLOY_ROLE_ARN", java.lang.String.class);
        DEFAULT_FILE_ASSETS_BUCKET_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_FILE_ASSETS_BUCKET_NAME", java.lang.String.class);
        DEFAULT_IMAGE_ASSETS_REPOSITORY_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_IMAGE_ASSETS_REPOSITORY_NAME", java.lang.String.class);
        DEFAULT_QUALIFIER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.DefaultStackSynthesizer.class, "DEFAULT_QUALIFIER", java.lang.String.class);
    }

    /**
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DefaultStackSynthesizer(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.DefaultStackSynthesizerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public DefaultStackSynthesizer() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Register a Docker Image Asset.
     * <p>
     * Returns the parameters that can be used to refer to the asset inside the template.
     * <p>
     * @param asset This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.DockerImageAssetLocation addDockerImageAsset(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.DockerImageAssetSource asset) {
        return this.jsiiCall("addDockerImageAsset", software.amazon.awscdk.core.DockerImageAssetLocation.class, new Object[] { java.util.Objects.requireNonNull(asset, "asset is required") });
    }

    /**
     * Register a File Asset.
     * <p>
     * Returns the parameters that can be used to refer to the asset inside the template.
     * <p>
     * @param asset This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.FileAssetLocation addFileAsset(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.FileAssetSource asset) {
        return this.jsiiCall("addFileAsset", software.amazon.awscdk.core.FileAssetLocation.class, new Object[] { java.util.Objects.requireNonNull(asset, "asset is required") });
    }

    /**
     * Bind to the stack this environment is going to be used on.
     * <p>
     * Must be called before any of the other methods are called.
     * <p>
     * @param stack This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Stack stack) {
        this.jsiiCall("bind", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(stack, "stack is required") });
    }

    /**
     * Synthesize all artifacts required for the stack into the session.
     * <p>
     * @param session This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void synthesizeStackArtifacts(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.ISynthesisSession session) {
        this.jsiiCall("synthesizeStackArtifacts", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(session, "session is required") });
    }

    /**
     * Default asset publishing role ARN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_ASSET_PUBLISHING_ROLE_ARN;

    /**
     * Default CloudFormation role ARN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_CLOUDFORMATION_ROLE_ARN;

    /**
     * Default deploy role ARN.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_DEPLOY_ROLE_ARN;

    /**
     * Default file assets bucket name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_FILE_ASSETS_BUCKET_NAME;

    /**
     * Default image assets repository name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_IMAGE_ASSETS_REPOSITORY_NAME;

    /**
     * Default ARN qualifier.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String DEFAULT_QUALIFIER;

    /**
     * A fluent builder for {@link software.amazon.awscdk.core.DefaultStackSynthesizer}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.core.DefaultStackSynthesizerProps.Builder props;

        private Builder() {
        }

        /**
         * External ID to use when assuming role for asset publishing.
         * <p>
         * Default: - No external ID
         * <p>
         * @return {@code this}
         * @param assetPublishingExternalId External ID to use when assuming role for asset publishing. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder assetPublishingExternalId(final java.lang.String assetPublishingExternalId) {
            this.props().assetPublishingExternalId(assetPublishingExternalId);
            return this;
        }

        /**
         * The role to use to publish assets to this environment.
         * <p>
         * You must supply this if you have given a non-standard name to the publishing role.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_ASSET_PUBLISHING_ROLE_ARN
         * <p>
         * @return {@code this}
         * @param assetPublishingRoleArn The role to use to publish assets to this environment. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder assetPublishingRoleArn(final java.lang.String assetPublishingRoleArn) {
            this.props().assetPublishingRoleArn(assetPublishingRoleArn);
            return this;
        }

        /**
         * The role CloudFormation will assume when deploying the Stack.
         * <p>
         * You must supply this if you have given a non-standard name to the execution role.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_CLOUDFORMATION_ROLE_ARN
         * <p>
         * @return {@code this}
         * @param cloudFormationExecutionRole The role CloudFormation will assume when deploying the Stack. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudFormationExecutionRole(final java.lang.String cloudFormationExecutionRole) {
            this.props().cloudFormationExecutionRole(cloudFormationExecutionRole);
            return this;
        }

        /**
         * The role to assume to initiate a deployment in this environment.
         * <p>
         * You must supply this if you have given a non-standard name to the publishing role.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_DEPLOY_ROLE_ARN
         * <p>
         * @return {@code this}
         * @param deployRoleArn The role to assume to initiate a deployment in this environment. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deployRoleArn(final java.lang.String deployRoleArn) {
            this.props().deployRoleArn(deployRoleArn);
            return this;
        }

        /**
         * Name of the S3 bucket to hold file assets.
         * <p>
         * You must supply this if you have given a non-standard name to the staging bucket.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_FILE_ASSETS_BUCKET_NAME
         * <p>
         * @return {@code this}
         * @param fileAssetsBucketName Name of the S3 bucket to hold file assets. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder fileAssetsBucketName(final java.lang.String fileAssetsBucketName) {
            this.props().fileAssetsBucketName(fileAssetsBucketName);
            return this;
        }

        /**
         * Name of the ECR repository to hold Docker Image assets.
         * <p>
         * You must supply this if you have given a non-standard name to the ECR repository.
         * <p>
         * The placeholders <code>${Qualifier}</code>, <code>${AWS::AccountId}</code> and <code>${AWS::Region}</code> will
         * be replaced with the values of qualifier and the stack's account and region,
         * respectively.
         * <p>
         * Default: DefaultStackSynthesizer.DEFAULT_IMAGE_ASSETS_REPOSITORY_NAME
         * <p>
         * @return {@code this}
         * @param imageAssetsRepositoryName Name of the ECR repository to hold Docker Image assets. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder imageAssetsRepositoryName(final java.lang.String imageAssetsRepositoryName) {
            this.props().imageAssetsRepositoryName(imageAssetsRepositoryName);
            return this;
        }

        /**
         * Qualifier to disambiguate multiple environments in the same account.
         * <p>
         * You can use this and leave the other naming properties empty if you have deployed
         * the bootstrap environment with standard names but only differnet qualifiers.
         * <p>
         * Default: - Value of context key '
         * <p>
         * @return {@code this}
         * @param qualifier Qualifier to disambiguate multiple environments in the same account. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder qualifier(final java.lang.String qualifier) {
            this.props().qualifier(qualifier);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.core.DefaultStackSynthesizer}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.DefaultStackSynthesizer build() {
            return new software.amazon.awscdk.core.DefaultStackSynthesizer(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.core.DefaultStackSynthesizerProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.core.DefaultStackSynthesizerProps.Builder();
            }
            return this.props;
        }
    }
}
